package de.fitko.fitconnect.api.services.validation;

import de.fitko.fitconnect.api.domain.model.metadata.Metadata;
import de.fitko.fitconnect.api.domain.model.metadata.attachment.Attachment;
import de.fitko.fitconnect.api.domain.model.metadata.data.Data;
import de.fitko.fitconnect.api.domain.model.submission.SubmissionSubmit;
import de.fitko.fitconnect.api.domain.validation.ValidationResult;

/**
 * A validator that ensures the integrity of the transferred {@link Metadata} of a {@link SubmissionSubmit}.
 * It provides the validation of schema and hash values.
 *
 * @see <a href="https://docs.fitko.de/fit-connect/docs/sending/metadata#integrity">Metadata Integrity</a>
 */
public interface MetadataValidator {

    /**
     * Validates the metadata against a given schema.
     *
     * @param metadata the current metadata object that should be validated
     * @param jsonSchema the schema the {@link Metadata} is validated against
     *
     * @return a {@link ValidationResult} with an optional error
     */
    ValidationResult validateMetadataSchema(final Metadata metadata, final String jsonSchema);

    /**
     * Checks if the message digest hashes of the metadata´s {@link Data} and {@link Attachment}s
     * are correct.
     *
     * @param metadata the current {@link Metadata} object that should be validated
     *
     * @return a {@link ValidationResult} with an optional error
     */
    ValidationResult validateMetadataHashValues(final Metadata metadata);
}
